==> PPDF_1_1.zip: PubMedPDF/autorun_wopmid.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/xml.php";
	include "include/conn.php";
	include "include/db.php";

	$updir = "uploads_xml/";
	if( $handle = opendir($updir) ){
		while ( $file = readdir( $handle ) ){
			if( $file != "." && $file != ".." ){

				$pm_data = RETRIEVE_XML( $updir, $file );
				$Author = "";
				$Authors = explode(",",$pm_data[a]);
				foreach($Authors as $a){
					$a = trim($a);
					$Author .= $a.", ";
				}
				$pm_data[a] = substr($Author, 0, -2);
				
#				$title = trim( $pm_data[t] );
#				$title = substr( $title, 0, 10 );
				
#				$data_id = $pm_data[y]."_".$pm_data[a]."_".$pm_data[j]."_".$pm_data[v]."_".$pm_data[p]."_".$title;
				$data_id = $pm_data[y]."_".$pm_data[a]."_".$pm_data[j]."_".$pm_data[v]."_".$pm_data[p];
				$data_id = str_replace( array(' ', ','), array('_', '~'), $data_id );

				echo $file."<br>";
				echo $data_id."<br>";

				$sql = "SELECT * FROM ".$T_ID." WHERE Custom_t1='$data_id';";
				$res = mysql_query($sql, $conn);

				if (!mysql_num_rows($res)) {
					registDB( $pm_data );
				} else {
					echo "\"$pm_data[t]\" is existed<br>";
				}
			}
		}
	}

	include (XOOPS_ROOT_PATH."/footer.php");


# -------------------------------------------------------------



function registDB( $pm_data ) {

	include "include/conn.php";

	$sql = "SELECT * FROM ".$T_JOURNAL." WHERE Journal='$pm_data[j]';";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	if (!mysql_num_rows($res)) {

		$data[j] = $pm_data[j];
		$data[j_jp] = $pm_data[j_jp];
//		$data[j_url] = $pm_data[j_url];
//		$data[e] = $pm_data[e];
//		$data[pub] = $pm_data[pub];
//		(@$_POST["book"]) ? $data[bk] = "1" : $data[bk] = "0";

		REG_JOURNAL($data);

		echo "<div class=\"pt\">"."New journal is registered"."</div>";
		echo "Name in English : ".$data[j]."<br>";
		echo "Name in other Language : ".$data[j_jp]."<br>";
		echo "Website : ".$data[j_url]."<br>";
		echo "Editors : ".$data[e]."<br>";
		echo "Publisher : ".$data[pub]."<br><br>";
	}

	# registration of bibliography
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	$seq_no = DB($pm_data, $user);

	# ID number -> PMID for original content
	$sql = "UPDATE ".$T_ID." SET PMID=";
	$sql.= "'-".$seq_no."'"." WHERE id=$seq_no;"; 
	$res = mysql_query($sql, $conn);

	echo "<b>Title: </b>".$pm_data[t]."<br>";
	echo "<b>Title: </b>".$pm_data[t_jp]."<br>";
	echo "<b>Author(s): </b>".$pm_data[a]."<br>";
	echo "<b>Author(s): </b>".$pm_data[a_jp]."<br>";
	echo "<b>Journal: </b>".$pm_data[j]."<br>";
	echo "<b>Journal: </b>".$pm_data[j_jp]."<br>";
	echo "<b>Volume: </b>".$pm_data[v]."<br>";
	echo "<b>Pages: </b>".$pm_data[p]."<br>";
	echo "<b>Year: </b>".$pm_data[y]."<br>";
	echo "<b>Abstract: </b><br>".$pm_data[ab]."<br>";
	echo "<br>";
}

?>

==> PPDF_1_4.zip: PubMedPDF/autorun_wopmid.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/xml.php";
	include "include/conn.php";
	include "include/db.php";
	include "include/wopmid.php";

	$updir = "uploads_xml/";
	if( $handle = opendir($updir) ){
		while ( $file = readdir( $handle ) ){
			if( $file != "." && $file != ".." ){

				$pm_data = RETRIEVE_XML( $updir, $file );
				$Author = "";
				$Authors = explode(",",$pm_data[a]);
				foreach($Authors as $a){
					$a = trim($a);
					$Author .= $a.", ";
				}
				$pm_data[a] = substr($Author, 0, -2);
				
				$title = trim( $pm_data[t] );
//				$title = substr( $title, 0, 10 );
				
//				$data_id = $pm_data[y]."_".$pm_data[a]."_".$pm_data[j]."_".$pm_data[v]."_".$pm_data[p]."_".$title;
/*
				$data_id = $pm_data[y]."_".$pm_data[a]."_".$pm_data[j]."_".$pm_data[v]."_".$pm_data[p];
				$data_id = str_replace( array(' ', ','), array('_', '~'), $data_id );
*/
			        $data_id = wopmid($pm_data[y], $pm_data[a], $pm_data[j], $pm_data[v], $pm_data[p], $title);

				echo $file."<br>";
				echo $data_id."<br>";

				$sql = "SELECT * FROM ".$T_ID." WHERE Custom_t1='$data_id';";
				$res = mysql_query($sql, $conn);

				if (!mysql_num_rows($res)) {
					registDB( $pm_data );
				} else {
					echo "\"$pm_data[t]\" is existed<br>";
				}
			}
		}
	}

	include (XOOPS_ROOT_PATH."/footer.php");


# -------------------------------------------------------------



function registDB( $pm_data ) {

	include "include/conn.php";

	$sql = "SELECT * FROM ".$T_JOURNAL." WHERE Journal='$pm_data[j]';";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	if (!mysql_num_rows($res)) {

		$data[j] = $pm_data[j];
		$data[j_jp] = $pm_data[j_jp];
//		$data[j_url] = $pm_data[j_url];
//		$data[e] = $pm_data[e];
//		$data[pub] = $pm_data[pub];
//		(@$_POST["book"]) ? $data[bk] = "1" : $data[bk] = "0";

		REG_JOURNAL($data);

		echo "<div class=\"pt\">"."New journal is registered"."</div>";
		echo "Name in English : ".$data[j]."<br>";
		echo "Name in other Language : ".$data[j_jp]."<br>";
		echo "Website : ".$data[j_url]."<br>";
		echo "Editors : ".$data[e]."<br>";
		echo "Publisher : ".$data[pub]."<br><br>";
	}

	# registration of bibliography
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	$seq_no = DB($pm_data, $user);

	# ID number -> PMID for original content
	$sql = "UPDATE ".$T_ID." SET PMID=";
	$sql.= "'-".$seq_no."'"." WHERE id=$seq_no;"; 
	$res = mysql_query($sql, $conn);

	echo "<b>Title: </b>".$pm_data[t]."<br>";
	echo "<b>Title: </b>".$pm_data[t_jp]."<br>";
	echo "<b>Author(s): </b>".$pm_data[a]."<br>";
	echo "<b>Author(s): </b>".$pm_data[a_jp]."<br>";
	echo "<b>Journal: </b>".$pm_data[j]."<br>";
	echo "<b>Journal: </b>".$pm_data[j_jp]."<br>";
	echo "<b>Volume: </b>".$pm_data[v]."<br>";
	echo "<b>Pages: </b>".$pm_data[p]."<br>";
	echo "<b>Year: </b>".$pm_data[y]."<br>";
	echo "<b>Abstract: </b><br>".$pm_data[ab]."<br>";
	echo "<br>";
}

?>
